@@ -56,14 +56,30 @@ class AerosolModelColorado(AerosolModel):
         height = inputs.room_height
         area = inputs.room_area  # width * length
         volume = area * height
+        event_duration = inputs.event_duration  # 50 / 60 # hours
 
+        # PRESSURE
         pressure = params.pressure  # 0.95
-        temperature = params.temperature  # 20
-        # relative_humidity = params.relative_humidity # 50
+
+        # TEMPERATURE
+        temperature_ext = params.temperature
+        temperature_int = inputs.temperature
+        area_transfer = 2*math.sqrt(area)*height # suppose half of the room is exposed
+        
+        heat_transfer_coefficient = 1.2 # W / m2 K # https://www.researchgate.net/publication/325614742_A_Dynamic_Model_for_Indoor_Temperature_Prediction_in_Buildings
+        heat_transfer = heat_transfer_coefficient*area_transfer # W/K
+        heat_capacity_coefficient = 144e3 # J/(m2 K) # https://www.researchgate.net/publication/325614742_A_Dynamic_Model_for_Indoor_Temperature_Prediction_in_Buildings
+        heat_capacity = heat_capacity_coefficient*area_transfer # J/K
+        heat_per_person = 150 # W # https://www.researchgate.net/publication/271444362_Predicting_Energy_Requirement_for_Cooling_the_Building_Using_Artificial_Neural_Network/figures?lo=1
+        P = heat_per_person*inputs.num_people  # W
+        Q = inputs.room_ventilation_rate * volume / 3600 # m3 / s  # https://www.ncbi.nlm.nih.gov/books/NBK143289/
+        delta_time = event_duration * 3600 # seconds
+        temperature = (temperature_int + delta_time*(P/heat_capacity + temperature_ext*heat_transfer/heat_capacity + temperature_ext*Q/volume))/(1 + delta_time*heat_transfer/heat_capacity + delta_time*Q/volume)
+
+
+        relative_humidity = params.relative_humidity # 50 # TODO: include formula
+
         CO2_background = params.CO2_background  # 415
-
-        event_duration = inputs.event_duration  # 50 / 60 # h
-
         ventilation = inputs.room_ventilation_rate  # 3
         decay_rate = params.decay_rate  # 0.62
         deposition_rate = params.deposition_rate  # 0.3
@@ -95,7 +111,7 @@ class AerosolModelColorado(AerosolModel):
         breathing_rate = params.breathing_rate  # 0.52
         breathing_rate_relative = breathing_rate / (0.0048 * 60)
         CO2_emission_person = params.CO2_emission_person  # 0.005
-        CO2_emission = CO2_emission_person * num_people / pressure * (273.15 + temperature) / 273.15
+        CO2_emission = CO2_emission_person * num_people / pressure * (273.15 + temperature_int) / 273.15
 
         quanta_exhalation = params.quanta_exhalation  # 25
         quanta_enhancement = params.quanta_enhancement  # 1
@@ -157,4 +173,5 @@ class AerosolModelColorado(AerosolModel):
         # CO2_probability_infection_=  CO2_reinhaled_ppm / 1e4 / probability_infection
         # CO2_inhale_ppm = CO2_mixing_ratio_delta * event_duration * 0.01 / probability_infection + CO2_background
 
-        return CO2_mixing_ratio, quanta_inhaled_per_person, quanta_concentration
+        # return CO2_mixing_ratio, quanta_inhaled_per_person, quanta_concentration
+        return CO2_mixing_ratio, quanta_inhaled_per_person, quanta_concentration, temperature, relative_humidity
